<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Coumpressioun dei css e javascript en la prima-testa dei pàgina html de <code>ecrire/</code> e/o dóu sit pùblicou',
	'compresseur_slogan' => 'Coumpressioun dei css e javascript',
];
